package com.zy.bms.controller;

import com.zy.bms.common.ServerResponse;
import com.zy.bms.model.UserIdioms;
import com.zy.bms.service.IdiomsService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 用户常用语
 *
 * @author yang xiao kun
 * create on 2021/1/22
 */
@RestController
@RequestMapping("zy4g/api/idioms")
public class IdiomsController {

    @Resource
    IdiomsService userIdiomsService;

    /**
     * 通过用户ID 查询用户常用语
     *
     * @param userId 用户ID
     */
    @GetMapping("getList.do")
    public ServerResponse getList(String userId) {
        return ServerResponse.createBySuccess(userIdiomsService.getListByUserId(userId));
    }

    /**
     * 添加常用语
     */
    @PostMapping("save.do")
    public ServerResponse save(UserIdioms entity) {
        if (userIdiomsService.countByUserId(entity.getUserId()) > 10) {
            return ServerResponse.createByWarningMsg("最多添加十条常用语");
        }
        return ServerResponse.createBySuccess(userIdiomsService.save(entity));
    }

    /**
     * 通过ID删除常用语
     */
    @PostMapping("delById.do")
    public ServerResponse delById(Integer id, String userId) {
        return ServerResponse.createBySuccess(userIdiomsService.delById(id, userId));
    }
}
