package com.zy.bms.service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zy.bms.common.io.wechat.DeviceHistoryIO;
import com.zy.bms.common.vo.LocationHistoryVo;
import com.zy.bms.mapper.DeviceLocationMapper;
import com.zy.bms.model.DeviceLocation;
import com.zy.bms.redis.DeviceManager;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 设备位置信息相关
 *
 * @author chenyi
 * Create on 2020/4/10
 */
@Service
public class DeviceLocationService extends ServiceImpl<DeviceLocationMapper, DeviceLocation> {

    @Resource
    private DeviceManager redisDeviceManager;

    /**
     * 获取设备的最新位置信息
     * (优先查询redis缓存,再查询数据库)
     *
     * @param deviceId 设备ID
     */
    public DeviceLocation getLocation(String deviceId) {
        DeviceLocation result = redisDeviceManager.getLocation(deviceId);
        if (result == null) {
            result = baseMapper.getLatestLocation(deviceId);
        }
        return result;
    }

    /**
     * 查看设备历史轨迹
     *
     * @param io 查询入参
     */
    public List<LocationHistoryVo> getHistory(DeviceHistoryIO io) {
        return baseMapper.getHistory(io);
    }

}
