package com.zy.bms.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zy.bms.common.io.pc.DeviceIO;
import com.zy.bms.mapper.DeviceMapper;
import com.zy.bms.model.Device;
import com.zy.bms.model.DeviceLocation;
import com.zy.bms.redis.DeviceManager;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.LinkedList;
import java.util.List;


/**
 * 设备信息相关
 *
 * @author chenyi
 * Create on 2020/4/10
 */
@Service
public class DeviceService extends ServiceImpl<DeviceMapper, Device> {

    @Resource
    private DeviceManager redisService;

    /**
     * 后台
     * 获取所有设备的最新定位信息
     */
    public List<DeviceLocation> getLatestLocation() {
        List<String> clientIds = baseMapper.getClientIdList();
        List<DeviceLocation> result = new LinkedList<>();
        for (String clientId : clientIds) {
            DeviceLocation item = redisService.getLocation(clientId);
            if (item != null) result.add(item);
        }
        return result;
    }

    /**
     * 后台
     * 分页查询设备列表
     *
     * @param io 查询条件
     */
    public IPage<Device> getListPage(DeviceIO io) {
        Page<Device> page = new Page<>(io.getCurrent(), io.getSize());
        return baseMapper.getListPage(page, io);
    }

    /**
     * 通过设备 num 获取设备信息
     *
     * @param num 设备号
     */
    public Device getByNum(String num) {
        QueryWrapper<Device> queryWrapper = new QueryWrapper<Device>().eq("num", num);
        return baseMapper.selectOne(queryWrapper);
    }

    /**
     * 更新设备名称
     *
     * @param num  设备号
     * @param name 名称
     */
    public boolean updateName(String num, String name) {
        return baseMapper.updateName(num, name) > 0;
    }

    /**
     * 通过设备 clientId 获取设备信息
     *
     * @param clientId 设备 MQTT 登录账号
     */
    public Device getByClientId(String clientId) {
        QueryWrapper<Device> queryWrapper = new QueryWrapper<Device>().eq("clientId", clientId);
        return baseMapper.selectOne(queryWrapper);
    }
}
