package com.zy.bms.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zy.bms.common.io.wechat.UserDeviceRelationIO;
import com.zy.bms.mapper.UserDeviceRelationMapper;
import com.zy.bms.model.UserDeviceRelation;
import com.zy.bms.common.vo.DeviceRelationVo;
import com.zy.bms.utils.BeanUtil;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;


/**
 * 用户设备绑定关系Service
 *
 * @author chenyi
 * Create on 2020/4/10
 */
@Service
public class RelationService extends ServiceImpl<UserDeviceRelationMapper, UserDeviceRelation> {

    @Resource
    private DeviceService deviceService;

    /**
     * 添加绑定关系
     *
     * @param io 实体类
     */
    public void saveEntity(UserDeviceRelationIO io) {
        QueryWrapper<UserDeviceRelation> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("userId", io.getUserId()).eq("isDefault", 1);
        int isDefault = baseMapper.selectOne(queryWrapper) == null ? 1 : 0;
        UserDeviceRelation entity = BeanUtil.cast(io, UserDeviceRelation.class);
        entity.setIsDefault(isDefault);
        baseMapper.insert(entity);
        deviceService.updateName(io.getDeviceNum(), io.getDeviceName());
    }

    /**
     * 通过设备号删除绑定关系
     *
     * @param deviceNum 设备号
     */
    public void unbind(String deviceNum, String userId) {
        QueryWrapper<UserDeviceRelation> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("deviceNum", deviceNum);
        queryWrapper.eq("userId", userId);
        baseMapper.delete(queryWrapper);
    }

    /**
     * 查询用户绑定的设备集合
     *
     * @param userId 用户ID
     */
    public List<DeviceRelationVo> getListByUserId(String userId) {
        return baseMapper.getListByUserId(userId);
    }

    /**
     * 查询设备是否有绑定关系
     *
     * @param deviceNum 设备号
     */
    public boolean isBind(String deviceNum) {
        QueryWrapper<UserDeviceRelation> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("deviceNum", deviceNum);
        return baseMapper.selectCount(queryWrapper) > 0;
    }
}
