package com.zy.bms.service;

import com.zy.bms.model.SetBase;
import com.zy.bms.model.SetNews;
import com.zy.bms.utils.BeanUtil;
import com.zy.bms.common.io.wechat.*;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.time.LocalDateTime;

/**
 * 设备设置 Service
 *
 * @author chen_yi
 * Create on 2021/3/27
 */
@Component
public class SetService {

    @Resource
    private SetBaseService setBaseService;
    @Resource
    private SetToDeviceService setToDeviceService;
    @Resource
    private SetNewsService setNewsService;

    /**
     * 设置音量
     */
    public void setVolume(VolumeSetIO io) {
        //发送模板消息给设备
        setToDeviceService.setVolume(io);
        //保存数据库
        saveBaseSet(io);
    }

    /**
     * 设置定位频率
     */
    public void setGpsRate(GpsRateSetIO io) {
        //发送模板消息给设备
        setToDeviceService.setGpsRate(io);
        //保存数据库
        saveBaseSet(io);
    }

    /**
     * 自动接听
     */
    public void setAutoAnswer(AnswerSetIO io) {
        //发送模板消息给设备
        setToDeviceService.setAutoAnswer(io);
        //保存数据库
        saveBaseSet(io);
    }

    /**
     * 设置语音播报
     */
    public void setNews(NewsSetIO io) {
        //发送模板消息给设备
        setToDeviceService.sendNews(io);
        //保存数据库
        SetNews entity = BeanUtil.cast(io, SetNews.class);
        entity.setCreateTime(LocalDateTime.now());
        setNewsService.save(entity);
    }

    /**
     * 设置SOS紧急呼叫
     */
    public void setSOS(SosSetIO io) {
        //发送模板消息给设备
        setToDeviceService.setSOS(io);
        //保存数据库
        saveBaseSet(io);
    }

    /**
     * 设置持续定位
     */
    public void setContinue(ContinueSetIO io) {
        //发送模板消息给设备
        setToDeviceService.setContinue(io);
        //保存数据库
        saveBaseSet(io);
    }

    /**
     * 保存基本设置数据
     */
    private void saveBaseSet(Object io) {
        //保存数据库
        SetBase entity = BeanUtil.cast(io, SetBase.class);
        setBaseService.updateByDeviceId(entity);
    }
}
